==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Tarea"
 ,"Tareas"

]
, "Percent"
: "Porcentaje"

, "Completed"
: "Completado"

, "Due"
: "Apta"

, "Class"
: ""

, "Description"
: "Descripción"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organizador"

, "Priority"
: "Prioridad"

, "Status, Status"
: [
  "Estado"
 ,"Estados"

]
, "Lead"
: "Iniciativa"

, "Telephone"
: "Teléfono"

, "Email"
: "Email"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Tienes que proporcionar una fecha de vencimiento, ya que una alarma esta programada!"

, "Summary"
: "Resumen"

, "Due date"
: "Fecha apta"

, "Add Responsible ..."
: "Agregar Responsable..."

, "Notes"
: "Notas"

, "Enter description..."
: "Escribir descripción..."

, "Percentage"
: "Porcentaje"

, "Tasks"
: "Tareas"

, "to do list, to do lists"
: [
  "lista para hacer"
 ,"listas para hacer"

]
, "to do lists"
: "listas para hacer"

, "Quick Search"
: "Búsqueda Rápida"

, "Due Date"
: "Fecha Apta"

, "Responsible"
: "Responsable"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creada Por"

, "New Task"
: "Nueva Tarea"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "¿Realmente desea borrar la tarea seleccionada?"
 ,"¿Realmente desea borrar las tareas seleccionadas?"

]
, "Attachments"
: ""

, "Tags"
: "Etiquetas"

, "Lead name"
: ""

, "Add a task..."
: "Agregar una tarea..."

, "All my tasks"
: "Todas mis tareas"

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on Tasks startup"
: "El favorito por defecto se carga al iniciar las tareas"

, "Default Task List"
: "Lista de tareas por defecto"

, "The default task list to create new tasks in."
: "Lista de tareas por defecto para crear nuevas tareas en él."

, "Tasks status available"
: "Estado de la Tarea Disponible"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Posible estado de las tareas. Tenga en cuenta que el estado del asistente podría afectar otros sistemas de Tareas en la exportación o la sincronización."

, "No response"
: "No hay respuesta"

, "Cancelled"
: "Cancelado"

, "In process"
: "En proceso"

, "Task priorities available"
: "Prioridades de la tarea disponible"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Posible prioridad de las tareas. Tenga en cuenta que el estado del asistente podría afectar otros sistemas de Tareas en la exportación o la sincronización."

, "low"
: "baja"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgente"

, "manage shared task lists"
: "administrar lista de tareas compartidas"

, "Create new shared tasks lists"
: "Crear nueva lista de tareas compartidas"

, "manage shared tasks favorites"
: "gestionar tareas favoritas compartidas"

, "Create or update shared tasks favorites"
: "Crear o actualizar tareas favoritas compartidas"

, "%s's personal tasks"
: "Tareas personales de %s"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Todas las tareas de mis listas de tareas"

, "My open tasks"
: "Mis tareas abiertas"

, "My open tasks this week"
: "Mis tareas abiertas esta semana"

, "All tasks for me"
: "Todas las tareas para mi"

, "All tasks that I am responsible for"
: "Todas las tareas de mi responsabilidad para"

, "Last modified by me"
: "Última modificación por mi"

, "All tasks that I have last modified"
: "Todas las tareas que he modificado anteriormente"

, "Tasks without responsible"
: "Tareas sin responsable"

, "GENDER_Task"
: ""

, "Task"
: "Tarea"

, "Status"
: "Estado"

, "to do list"
: "lista para hacer"

, "Do you really want to delete the selected task?"
: "¿Realmente desea borrar la tarea seleccionada?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Tienes que proporcionar una fecha de vencimiento, ya que una alarma esta programada!"

, "Summary"
: "Resumen"

, "Due date"
: "Fecha apta"

, "Priority"
: "Prioridad"

, "Organizer"
: "Organizador"

, "Add Responsible ..."
: "Agregar Responsable..."

, "Notes"
: "Notas"

, "Enter description..."
: "Escribir descripción..."

, "Percentage"
: "Porcentaje"

, "Status, Status"
: [
  "Estado"
 ,"Estados"

]
, "Completed"
: "Completado"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "¿Realmente desea borrar la tarea seleccionada?"
 ,"¿Realmente desea borrar las tareas seleccionadas?"

]
, "Attachments"
: ""

, "Tags"
: "Etiquetas"

, "Lead name"
: ""

, "Add a task..."
: "Agregar una tarea..."

, "Due Date"
: "Fecha Apta"

, "Percent"
: "Porcentaje"

, "Responsible"
: "Responsable"

, "Task, Tasks"
: [
  "Tarea"
 ,"Tareas"

]
, "Tasks"
: "Tareas"

, "to do list, to do lists"
: [
  "lista para hacer"
 ,"listas para hacer"

]
, "to do lists"
: "listas para hacer"

, "Quick Search"
: "Búsqueda Rápida"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creada Por"

, "New Task"
: "Nueva Tarea"

, "All my tasks"
: "Todas mis tareas"

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on Tasks startup"
: "El favorito por defecto se carga al iniciar las tareas"

, "Default Task List"
: "Lista de tareas por defecto"

, "The default task list to create new tasks in."
: "Lista de tareas por defecto para crear nuevas tareas en él."

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Estado de la Tarea Disponible"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Posible estado de las tareas. Tenga en cuenta que el estado del asistente podría afectar otros sistemas de Tareas en la exportación o la sincronización."

, "No response"
: "No hay respuesta"

, "Cancelled"
: "Cancelado"

, "In process"
: "En proceso"

, "Task priorities available"
: "Prioridades de la tarea disponible"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Posible prioridad de las tareas. Tenga en cuenta que el estado del asistente podría afectar otros sistemas de Tareas en la exportación o la sincronización."

, "low"
: "baja"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgente"

, "%s's personal tasks"
: "Tareas personales de %s"

, "GENDER_Task"
: ""

, "Due"
: "Apta"

, "Class"
: ""

, "Description"
: "Descripción"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Iniciativa"

, "Telephone"
: "Teléfono"

, "Email"
: "Email"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Todas las tareas de mis listas de tareas"

, "My open tasks"
: "Mis tareas abiertas"

, "My open tasks this week"
: "Mis tareas abiertas esta semana"

, "All tasks for me"
: "Todas las tareas para mi"

, "All tasks that I am responsible for"
: "Todas las tareas de mi responsabilidad para"

, "Last modified by me"
: "Última modificación por mi"

, "All tasks that I have last modified"
: "Todas las tareas que he modificado anteriormente"

, "Tasks without responsible"
: "Tareas sin responsable"

, "manage shared task lists"
: "administrar lista de tareas compartidas"

, "Create new shared tasks lists"
: "Crear nueva lista de tareas compartidas"

, "manage shared tasks favorites"
: "gestionar tareas favoritas compartidas"

, "Create or update shared tasks favorites"
: "Crear o actualizar tareas favoritas compartidas"

, "Status"
: "Estado"

, "Do you really want to delete the selected task?"
: "¿Realmente desea borrar la tarea seleccionada?"

, "Task"
: "Tarea"

, "to do list"
: "lista para hacer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
